Exceptions
==========

.. module:: acmeow.exceptions

All exceptions inherit from ``AcmeError``.

AcmeError
---------

.. autoclass:: acmeow.AcmeError
   :members:
   :show-inheritance:

AcmeServerError
---------------

.. autoclass:: acmeow.AcmeServerError
   :members:
   :show-inheritance:

AcmeAuthenticationError
-----------------------

.. autoclass:: acmeow.AcmeAuthenticationError
   :members:
   :show-inheritance:

AcmeAuthorizationError
----------------------

.. autoclass:: acmeow.AcmeAuthorizationError
   :members:
   :show-inheritance:

AcmeOrderError
--------------

.. autoclass:: acmeow.AcmeOrderError
   :members:
   :show-inheritance:

AcmeCertificateError
--------------------

.. autoclass:: acmeow.AcmeCertificateError
   :members:
   :show-inheritance:

AcmeConfigurationError
----------------------

.. autoclass:: acmeow.AcmeConfigurationError
   :members:
   :show-inheritance:

AcmeNetworkError
----------------

.. autoclass:: acmeow.AcmeNetworkError
   :members:
   :show-inheritance:

AcmeTimeoutError
----------------

.. autoclass:: acmeow.AcmeTimeoutError
   :members:
   :show-inheritance:

AcmeRateLimitError
------------------

.. autoclass:: acmeow.AcmeRateLimitError
   :members:
   :show-inheritance:

AcmeDnsError
------------

.. autoclass:: acmeow.AcmeDnsError
   :members:
   :show-inheritance:
